<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About</source>
        <translation type="obsolete">O prehliadači</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Autori</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
    <message>
        <source>Lightweight WebKit-based web browser</source>
        <translation>Jednoduchý webový prehliadač založený na WebKite</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavrieť</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2008 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2008 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WebKit version: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AcceptLanguage</name>
    <message>
        <source>Languages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Languages: in order of preference:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="unfinished">&amp;Vymazať</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockBlockedNetworkReply</name>
    <message>
        <source>Blocked by AdBlockRule: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockDialog</name>
    <message>
        <source>Add Custom Rule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Learn more about writing rules...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Subscription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse Subscriptions...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Subscription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AdBlock Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable AdBlock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockManager</name>
    <message>
        <source>Custom Rules</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockModel</name>
    <message>
        <source>Rule</source>
        <translation type="unfinished">Pravidlo</translation>
    </message>
</context>
<context>
    <name>AdBlockSchemeAccessHandler</name>
    <message>
        <source>Subscribe?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subscribe to this AdBlock subscription?
%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddBookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Pridať záložku</translation>
    </message>
    <message>
        <source>Type a name for the bookmark, and choose where to keep it.</source>
        <translation>Napíšte názov záložky a vyberte, kam ju chcete uložiť.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation type="unfinished">Pridať zložku</translation>
    </message>
</context>
<context>
    <name>AutoFillDialog</name>
    <message>
        <source>Form Passwords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoFillManager</name>
    <message>
        <source>&lt;b&gt;Would you like to save this password?&lt;/b&gt;&lt;br&gt;         To review passwords you have saved and remove them, open the AutoFill pane of preferences.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Never for this site</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoFillModel</name>
    <message>
        <source>WebSite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <source>Open</source>
        <translation>Otvoriť</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Vymazať</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nová zložka</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Záložky</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Vymazať</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Pridať zložku</translation>
    </message>
    <message>
        <source>Open in New Tab</source>
        <translation>Otvoriť v novom paneli</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksManager</name>
    <message>
        <source>Error when loading bookmarks on line %1, column %2:
%3</source>
        <translation>Chyba pri načítavaní založiek na riadku %1, stĺpci %2: %3</translation>
    </message>
    <message>
        <source>Toolbar Bookmarks</source>
        <translation>Nástrojová lišta záložiek</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Otvoriť súbor</translation>
    </message>
    <message>
        <source>XBEL (*.xbel *.xml)</source>
        <translation type="obsolete">XBEL (*.xbel *.xml)</translation>
    </message>
    <message>
        <source>Imported %1</source>
        <translation>Importované %1</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Uložiť súbor</translation>
    </message>
    <message>
        <source>%1 Bookmarks.xbel</source>
        <translation>%1 Bookmarks.xbel</translation>
    </message>
    <message>
        <source>Export error</source>
        <translation>Chyba pri exporte</translation>
    </message>
    <message>
        <source>error saving bookmarks</source>
        <translation>chyba pri ukladaní záložiek</translation>
    </message>
    <message>
        <source>Remove Bookmark</source>
        <translation>Vymazať záložku</translation>
    </message>
    <message>
        <source>Insert Bookmark</source>
        <translation>Vložiť záložku</translation>
    </message>
    <message>
        <source>Name Change</source>
        <translation type="obsolete">Zmena názvu</translation>
    </message>
    <message>
        <source>Address Change</source>
        <translation type="obsolete">Zmena adresy</translation>
    </message>
    <message>
        <source>Bookmarks Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Change</source>
        <comment>Undo bookmark title change</comment>
        <translation type="unfinished">Zmena názvu</translation>
    </message>
    <message>
        <source>Address Change</source>
        <comment>Undo bookmark url change</comment>
        <translation type="unfinished">Zmena adresy</translation>
    </message>
    <message>
        <source>XBEL bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HTML Netscape bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>htmlToXBel tool required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading Bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error when loading HTML bookmarks: %1
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksMenu</name>
    <message>
        <source>Open in Tabs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksModel</name>
    <message>
        <source>Title</source>
        <translation>Titulok</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
</context>
<context>
    <name>BookmarksToolBar</name>
    <message>
        <source>Bookmark</source>
        <translation type="obsolete">Záložky</translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished">Otvoriť</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation type="unfinished">O&amp;tvoriť v novom paneli</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation type="unfinished">Pridať záložku ...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="obsolete">Záložky</translation>
    </message>
</context>
<context>
    <name>BrowserApplication</name>
    <message>
        <source>There are %1 windows and %2 tabs open
Do you want to quit anyway?</source>
        <translation>Máte otvorených %1 okien a %2 panelov
Chcete ich všetky uzavrieť?</translation>
    </message>
    <message>
        <source>Restore failed</source>
        <translation>Obnovenie zlyhalo</translation>
    </message>
    <message>
        <source>The saved session will not be restored because Arora crashed while trying to restore this session.</source>
        <translation type="obsolete">Uložená relácia nebude obnovená, pretože Arora spadla pri pokuse o jej obnovenie.</translation>
    </message>
    <message>
        <source> (Change: %1 %2)</source>
        <translation type="obsolete">(Zmena: %1 %2)</translation>
    </message>
    <message>
        <source>Arora crashed while trying to restore this session.  Should I try again?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrowserMainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Súbor</translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation>&amp;Nové okno</translation>
    </message>
    <message>
        <source>&amp;Open File...</source>
        <translation>Otvoriť &amp;soubor...</translation>
    </message>
    <message>
        <source>Open &amp;Location...</source>
        <translation>&amp;Otvoriť adresu ...</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Uložiť ako...</translation>
    </message>
    <message>
        <source>&amp;Import Bookmarks...</source>
        <translation>&amp;Importovať záložky ...</translation>
    </message>
    <message>
        <source>&amp;Export Bookmarks...</source>
        <translation>&amp;Exportovať záložky ...</translation>
    </message>
    <message>
        <source>P&amp;rint Preview...</source>
        <translation>Ná&amp;hľad tlače ...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Tlač ...</translation>
    </message>
    <message>
        <source>Private &amp;Browsing...</source>
        <translation>Súkro&amp;mné prehliadanie ...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>U&amp;končiť</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Úpr&amp;avy</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Späť</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Zn&amp;ovu</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>&amp;Vystrihnúť</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopírovať</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>V&amp;ložiť</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>Ná&amp;jsť</translation>
    </message>
    <message>
        <source>Ctrl+,</source>
        <translation>Ctrl+,</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Zobraziť</translation>
    </message>
    <message>
        <source>Shift+Ctrl+B</source>
        <translation type="obsolete">Shift+Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Ctrl+/</source>
        <translation>Ctrl+/</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>Z&amp;astaviť</translation>
    </message>
    <message>
        <source>Page S&amp;ource</source>
        <translation>&amp;Zdrojový kód stránky</translation>
    </message>
    <message>
        <source>Ctrl+Alt+U</source>
        <translation>Ctrl+Alt+U</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Celá obrazovka</translation>
    </message>
    <message>
        <source>Hi&amp;story</source>
        <translation>&amp;História</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Späť</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Vpred</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Domov</translation>
    </message>
    <message>
        <source>Restore Last Session</source>
        <translation>Obnoviť poslednú reláciu</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>Zál&amp;ožky</translation>
    </message>
    <message>
        <source>Manage Bookmarks...</source>
        <translation type="obsolete">Spravovať záložky ...</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Pridať záložku ...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Okno</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Nástroje</translation>
    </message>
    <message>
        <source>Web &amp;Search</source>
        <translation>&amp;Hľadanie na webe</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <comment>Web Search</comment>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Enable Web &amp;Inspector</source>
        <translation>Povoliť Web &amp;Inspector</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Nápo&amp;veda</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;Arora</source>
        <translation type="obsolete">O &amp;Arore</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>Navigácia</translation>
    </message>
    <message>
        <source>Show Status Bar</source>
        <translation>Zobraziť stavový riadok</translation>
    </message>
    <message>
        <source>Hide Status Bar</source>
        <translation>Skryť stavový riadok</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation>Zobraziť panel nástrojov</translation>
    </message>
    <message>
        <source>Hide Toolbar</source>
        <translation>Skryť panel nástrojov</translation>
    </message>
    <message>
        <source>Arora</source>
        <translation type="obsolete">Arora</translation>
    </message>
    <message>
        <source>%1 - Arora</source>
        <comment>Page title and Browser name</comment>
        <translation>%1 - Arora</translation>
    </message>
    <message>
        <source>Open Web Resource</source>
        <translation>Otvoriť webovú stránku</translation>
    </message>
    <message>
        <source>Web Resources (*.html *.htm *.svg *.png *.gif *.svgz);;All files (*.*)</source>
        <translation>Webové dokumenty (*.html *.htm *.svg *.png *.gif *.svgz);;Všetky súbory (*.*)</translation>
    </message>
    <message>
        <source>Print Document</source>
        <translation>Vytlačiť dokument</translation>
    </message>
    <message>
        <source>Are you sure you want to turn on private browsing?</source>
        <translation>Naozaj chcete zapnúť súkromné prehliadanie?</translation>
    </message>
    <message>
        <source>Are you sure you want to close the window?  There are %1 tabs open</source>
        <translation>Naozaj chcete zavrieť okno? Je v nom otvorených %1 panelov</translation>
    </message>
    <message>
        <source>Web Inspector</source>
        <translation>Webový inšpektor</translation>
    </message>
    <message>
        <source>The web inspector will only work correctly for pages that were loaded after enabling.
Do you want to reload all pages?</source>
        <translation>Webový inšpektor bude fungovať iba pre stránky načítané po jeho povoleni.
Chcete znovu načítať všetky stránky?</translation>
    </message>
    <message>
        <source>Stop loading the current page</source>
        <translation>Zastaví načítanie aktuálnej stránky</translation>
    </message>
    <message>
        <source>Reload the current page</source>
        <translation>Znovu načíta aktuálnu stránku</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Preberanie</translation>
    </message>
    <message>
        <source>Alt+Ctrl+L</source>
        <comment>Download Manager</comment>
        <translation type="obsolete">Alt+Ctrl+L</translation>
    </message>
    <message>
        <source>&amp;Clear Private Data</source>
        <translation>Zmazaž &amp;súkromné dáta</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <comment>Clear Private Data</comment>
        <translation>Ctrl+Shift+Delete</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not addded to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Ak je zapnuté súkromné prehliadanie, niektoré akcie narušujúce tvoje súkromie budú zakázané:&lt;ul&gt;&lt;li&gt; Stránky nie sú pridávané do histórie.&lt;/li&gt;&lt;li&gt; Položky sú automaticky vymazané z okna preberania.&lt;/li&gt;&lt;li&gt; Nové cookies nie sú uložené, aktuálne nebudú prístupné.&lt;/li&gt;&lt;li&gt; Ikony stránek nie sú ukládané, podobne ako relácie.&lt;/li&gt;&lt;li&gt; Hľadané výrazy nie sú pridávané do menu v políčku hľadania.&lt;/li&gt;&lt;/ul&gt;Pokiaľ nie je okno zavrené, je možné klikať Späť a Vpred pre vrátenie na skôr otvorené stránky.</translation>
    </message>
    <message>
        <source>Show Bookmarks Bar</source>
        <translation>Zobraziť panel záložiek</translation>
    </message>
    <message>
        <source>Hide Bookmarks Bar</source>
        <translation>Skryť panel záložiek</translation>
    </message>
    <message>
        <source>Find P&amp;revious</source>
        <translation>Nájsť &amp;predošlé</translation>
    </message>
    <message>
        <source>&amp;Reload Page</source>
        <translation>O&amp;bnoviť stránku</translation>
    </message>
    <message>
        <source>Make Text &amp;Bigger</source>
        <translation type="obsolete">Z&amp;väčšiť text</translation>
    </message>
    <message>
        <source>Make Text &amp;Normal</source>
        <translation type="obsolete">&amp;Normálna veľkosť textu</translation>
    </message>
    <message>
        <source>Make Text &amp;Smaller</source>
        <translation type="obsolete">Z&amp;menšiť text</translation>
    </message>
    <message>
        <source>Find Nex&amp;t</source>
        <translation>Náj&amp;sť dalšie</translation>
    </message>
    <message>
        <source>Prefere&amp;nces...</source>
        <translation type="obsolete">Nasta&amp;venia ...</translation>
    </message>
    <message>
        <source>Show Menu Bar</source>
        <translation>Ukázať menu</translation>
    </message>
    <message>
        <source>Switch application language </source>
        <translation>Vybrať jazyk</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;Text Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show All Bookmarks...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About &amp;%1</source>
        <comment>About Browser</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <comment>Download Manager</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished">Prednastavený</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+Ctrl+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Ad Block...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When private browsing is turned on, some actions concerning your privacy will be disabled:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Webpages are not added to the history.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items are automatically removed from the Downloads window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New cookies are not stored, current cookies can&apos;t be accessed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Site icons won&apos;t be stored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Session won&apos;t be saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Searches are not added to the pop-up menu in the search box.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No new network cache is written to disk.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Private Browsing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Vyčistiť</translation>
    </message>
</context>
<context>
    <name>ClearPrivateData</name>
    <message>
        <source>Clear Private Data</source>
        <translation>Vymazať súkromné dáta</translation>
    </message>
    <message>
        <source>Clear the following items:</source>
        <translation>Vymazať tieto položky:</translation>
    </message>
    <message>
        <source>&amp;Browsing History</source>
        <translation>&amp;História prehliadania</translation>
    </message>
    <message>
        <source>&amp;Download History</source>
        <translation>História &amp;preberania</translation>
    </message>
    <message>
        <source>&amp;Search History</source>
        <translation>História hľa&amp;dania</translation>
    </message>
    <message>
        <source>&amp;Cookies</source>
        <translation>&amp;Cookies</translation>
    </message>
    <message>
        <source>Website &amp;Icons</source>
        <translation>Ikony stránok</translation>
    </message>
    <message>
        <source>Clear &amp;Private Data</source>
        <translation>&amp;Vyčistiť súkromné dáta</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Zrušiť</translation>
    </message>
    <message>
        <source>C&amp;ached Web Pages</source>
        <translation>Stránky v &amp;cache</translation>
    </message>
</context>
<context>
    <name>ClickToFlash</name>
    <message>
        <source>Load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add %1 to Whitelist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from Whitelist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load Flash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClickToFlashSettings</name>
    <message>
        <source>Whitelist sites</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookieExceptionsModel</name>
    <message>
        <source>Website</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Povoliť</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Blokovať</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Povoliť pre reláciu</translation>
    </message>
    <message>
        <source>Rule</source>
        <translation>Pravidlo</translation>
    </message>
</context>
<context>
    <name>CookieModel</name>
    <message>
        <source>Website</source>
        <translation>Adresa</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Názov</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Cesta</translation>
    </message>
    <message>
        <source>Secure</source>
        <translation>Zabezpečené</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Vyprší</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Obsah</translation>
    </message>
    <message>
        <source>true</source>
        <translation>áno</translation>
    </message>
    <message>
        <source>false</source>
        <translation>nie</translation>
    </message>
    <message>
        <source>Session cookie</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookiesDialog</name>
    <message>
        <source>Cookies</source>
        <translation>Cookies</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Vymazať</translation>
    </message>
    <message>
        <source>Remove &amp;All Cookies</source>
        <translation>Vymazať &amp;všetky</translation>
    </message>
    <message>
        <source>Add &amp;Rule</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookiesExceptionsDialog</name>
    <message>
        <source>Cookie Exceptions</source>
        <translation>Výnimky pre cookies</translation>
    </message>
    <message>
        <source>New Exception</source>
        <translation>Nová výnimka</translation>
    </message>
    <message>
        <source>Domain:</source>
        <translation>Doména:</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Blokovať</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Povoliť pre reláciu</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Povoliť</translation>
    </message>
    <message>
        <source>Exceptions</source>
        <translation>Výnimky</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Vymazať</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Vymazať &amp;všetky</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Preberanie</translation>
    </message>
    <message>
        <source>Clean up</source>
        <translation>Vyčistiť</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 položiek</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Form</translation>
    </message>
    <message>
        <source>Ico</source>
        <translation>Ico</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Názov súboru</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Skúsiť znova</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zastaviť</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otvoriť</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Uložiť súbor</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Preberanie zrušené: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Chyba pri ukladaní: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Chyba siete: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation type="obsolete">sekúnd</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation type="obsolete">%1 z %2 (%3/s) %4</translation>
    </message>
    <message>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 z %2 - Zastavené</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation type="obsolete">bajtov</translation>
    </message>
    <message>
        <source>kB</source>
        <translation type="obsolete">KiB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation type="obsolete">MiB</translation>
    </message>
    <message numerus="yes">
        <source>- %n minutes remaining</source>
        <translation type="obsolete">
            <numerusform>- %n minúta ostáva</numerusform>
            <numerusform>- %n minúty ostávajú</numerusform>
            <numerusform>- %n minút ostáva</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>- %n seconds remaining</source>
        <translation type="obsolete">
            <numerusform>- %n sekunda ostáva</numerusform>
            <numerusform>- %n sekundy ostávajú</numerusform>
            <numerusform>- %n sekúnd ostáva</numerusform>
        </translation>
    </message>
    <message>
        <source>Error opening output file: %1</source>
        <translation>Chyba pri otváraní výstupného súboru: %1</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) - %4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download directory (%1) couldn&apos;t be created.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation>
            <numerusform>%n preberanie</numerusform>
            <numerusform>%n preberania</numerusform>
            <numerusform>%n preberaní</numerusform>
        </translation>
    </message>
    <message>
        <source>There are %1 downloads in progress
Do you want to quit anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n minutes remaining</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n seconds remaining</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>bytes</source>
        <translation type="unfinished">bajtov</translation>
    </message>
    <message>
        <source>kB</source>
        <translation type="unfinished">KiB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation type="unfinished">MiB</translation>
    </message>
    <message>
        <source>GB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileAccessReply</name>
    <message>
        <source>No Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening: %1: No such file or directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contents of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>Open</source>
        <translation>Otvoriť</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovať</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Vymazať</translation>
    </message>
    <message>
        <source>History</source>
        <translation>História</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Vymazať</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Vymazať &amp;všetky</translation>
    </message>
</context>
<context>
    <name>HistoryMenu</name>
    <message>
        <source>Show All History</source>
        <translation>Zobraziť celú históriu</translation>
    </message>
    <message>
        <source>Clear History</source>
        <translation>Vymazať históriu</translation>
    </message>
    <message>
        <source>Clear History...</source>
        <translation>Vymazať históriu ...</translation>
    </message>
    <message>
        <source>Do you want to clear the history?</source>
        <translation>Chcete vymazať históriu?</translation>
    </message>
</context>
<context>
    <name>HistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Názov</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresa</translation>
    </message>
</context>
<context>
    <name>HistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Dnes</translation>
    </message>
    <message numerus="yes">
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n položka</numerusform>
            <numerusform>%n položky</numerusform>
            <numerusform>%n položiek</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>JavaScriptAroraObject</name>
    <message>
        <source>Welcome to Arora!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arora Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search results provided by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Arora</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LanguageManager</name>
    <message>
        <source>Default</source>
        <translation type="obsolete">Prednastavený</translation>
    </message>
    <message>
        <source>Choose language</source>
        <translation>Vybrať jazyk</translation>
    </message>
    <message>
        <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
        <translation>&lt;p&gt;Aroru je možné používať v inom jazyku ako v tom,&lt;br&gt;ktorý je prednastavený v operačnom systéme.&lt;/p&gt;&lt;p&gt;Vybete si jazyk, ktorý má byť použitý&lt;/p&gt;</translation>
    </message>
    <message>
        <source>No translation files are installed at %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Zadajte užívateľské meno a heslo pre &quot;%1&quot; na %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Connect to proxy &quot;%1&quot; using:&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Pripojiť sa k proxy &quot;%1&quot; použitím:&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors?</source>
        <translation type="obsolete">Chyby SSL:

%1

%2

Chcete ignorovať tieto chyby?</translation>
    </message>
    <message>
        <source>Do you want to accept all these certificates?</source>
        <translation type="obsolete">Chcete prijať všetky tieto certifikáty?</translation>
    </message>
    <message>
        <source> - SSL Errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Do you want to ignore these errors?&lt;/qt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Issuer: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not valid before: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Valid until: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alternate Names:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Name</source>
        <translation type="obsolete">Názov</translation>
    </message>
</context>
<context>
    <name>NetworkMonitorDialog</name>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">&amp;Vymazať</translation>
    </message>
</context>
<context>
    <name>OpenSearchDialog</name>
    <message>
        <source>Open File</source>
        <translation type="unfinished">Otvoriť súbor</translation>
    </message>
    <message>
        <source>OpenSearch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must have at least one search engine in here.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OpenSearch Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Restore Defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSearchEngineModel</name>
    <message>
        <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comma-separated list of keywords that may be entered in the location barfollowed by search terms to search with this engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Názov</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSearchManager</name>
    <message>
        <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Vyžadované prihlásenie</translation>
    </message>
    <message>
        <source>DUMMY ICON</source>
        <translation>DUMMY ICON</translation>
    </message>
    <message>
        <source>INTRO TEXT DUMMY</source>
        <translation>INTRO TEXT DUMMY</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Užívateľské meno:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
</context>
<context>
    <name>PlainTextEditSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Neexistuje</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Prihlásenie k proxy</translation>
    </message>
    <message>
        <source>ICON</source>
        <translation type="obsolete">ICON</translation>
    </message>
    <message>
        <source>Connect to proxy</source>
        <translation>Pripojiť k proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Užívateľské meno:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The file is not an XBEL version 1.0 file.</source>
        <translation>Súbor nie je XBEL verzie 1.0.</translation>
    </message>
    <message>
        <source>Unknown title</source>
        <translation>Neznámý titulok</translation>
    </message>
    <message>
        <source>The file is not an OpenSearch 1.1 file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RequestModel</name>
    <message>
        <source>Address</source>
        <translation type="obsolete">Adresa</translation>
    </message>
</context>
<context>
    <name>SearchBanner</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Form</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation type="obsolete">TextLabel</translation>
    </message>
    <message>
        <source>&lt;</source>
        <translation type="obsolete">&lt;</translation>
    </message>
    <message>
        <source>&gt;</source>
        <translation type="obsolete">&gt;</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Hotovo</translation>
    </message>
    <message>
        <source>Highlight All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Hľadať</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>General</source>
        <translation>Hlavné</translation>
    </message>
    <message>
        <source>Set to current page</source>
        <translation>Nastav na aktuálnu stránku</translation>
    </message>
    <message>
        <source>Remove history items:</source>
        <translation>Odstrániť položky histórie:</translation>
    </message>
    <message>
        <source>After one day</source>
        <translation>Po jednom dni</translation>
    </message>
    <message>
        <source>After one week</source>
        <translation>Po jednom týždni</translation>
    </message>
    <message>
        <source>After two weeks</source>
        <translation>Po dvoch týždňoch</translation>
    </message>
    <message>
        <source>After one month</source>
        <translation>Po mesiaci</translation>
    </message>
    <message>
        <source>After one year</source>
        <translation>Po roku</translation>
    </message>
    <message>
        <source>Manually</source>
        <translation>Ručne</translation>
    </message>
    <message>
        <source>Open links from applications:</source>
        <translation>Otvoriť odkazy z aplikácií:</translation>
    </message>
    <message>
        <source>In a tab in the current window</source>
        <translation type="obsolete">V paneli v aktuálnom okne</translation>
    </message>
    <message>
        <source>In a new window</source>
        <translation>V novom okne</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Vzhľad</translation>
    </message>
    <message>
        <source>Standard font:</source>
        <translation>Štandardné písmo:</translation>
    </message>
    <message>
        <source>Times 16</source>
        <translation type="obsolete">Times 16</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>Vybrať ...</translation>
    </message>
    <message>
        <source>Fixed-width font:</source>
        <translation>Písmo s pevnou šírkou:</translation>
    </message>
    <message>
        <source>Courier 13</source>
        <translation type="obsolete">Courier 13</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Súkromie</translation>
    </message>
    <message>
        <source>Web Content</source>
        <translation>Obsah webu</translation>
    </message>
    <message>
        <source>Enable Plugins</source>
        <translation>Povoliť plug-iny</translation>
    </message>
    <message>
        <source>Enable Javascript</source>
        <translation>Povoliť JavaScript</translation>
    </message>
    <message>
        <source>Cookies</source>
        <translation>Cookies</translation>
    </message>
    <message>
        <source>Accept Cookies:</source>
        <translation>Prijímať cookies:</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Vždy</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nikdy</translation>
    </message>
    <message>
        <source>Only from sites you navigate to</source>
        <translation>Iba z navštívených stránok</translation>
    </message>
    <message>
        <source>Exceptions...</source>
        <translation>Výnimky ...</translation>
    </message>
    <message>
        <source>They expire</source>
        <translation>Vyprší</translation>
    </message>
    <message>
        <source>I exit the application</source>
        <translation>Ukončenie aplikácie</translation>
    </message>
    <message>
        <source>At most 90 days</source>
        <translation>Maximálne 90 dní</translation>
    </message>
    <message>
        <source>Cookies...</source>
        <translation>Cookies ...</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Socks5</source>
        <translation>Socks5</translation>
    </message>
    <message>
        <source>Http</source>
        <translation type="obsolete">Http</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>User Name:</source>
        <translation>Uživatelské meno:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Rozšírené</translation>
    </message>
    <message>
        <source>Style Sheet:</source>
        <translation>CSS štýl:</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Preberanie</translation>
    </message>
    <message>
        <source>Ask for a destination each time</source>
        <translation>Vždy sa pýtať na umiestnenie preberania</translation>
    </message>
    <message>
        <source>Use this destination:</source>
        <translation>Použiť toto umiestnenie:</translation>
    </message>
    <message>
        <source>On application exit</source>
        <translation>Pri ukončení aplikácie</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Panely</translation>
    </message>
    <message>
        <source>Select tabs and windows as they are created</source>
        <translation>Prepínať na okná a panely keď sú vytvorené</translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs</source>
        <translation type="obsolete">Vyžadovať potvrdenie pri zatváraní viacerých panelov</translation>
    </message>
    <message>
        <source>On startup:</source>
        <translation>Po spustení:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>Zobraziť moju domovskú stránku</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>Zobraziť prázdnu stránku</translation>
    </message>
    <message>
        <source>Restore windows and tabs from last time</source>
        <translation>Obnoviť okná a panely z poslednej relácie</translation>
    </message>
    <message>
        <source>Preferences</source>
        <translation>Nastavenia</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Domovská stránka:</translation>
    </message>
    <message>
        <source>View Images</source>
        <translation>Zobraziť obrázky</translation>
    </message>
    <message>
        <source>Keep Cookies Until:</source>
        <translation>Ponechat cookies pokiaľ:</translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation>Použiť proxy server</translation>
    </message>
    <message>
        <source>Host name:</source>
        <translation>Meno hostiteľa:</translation>
    </message>
    <message>
        <source>Show only one close button instead of one for each tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preferred languages for viewing webpages in:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Block Popup Windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opening links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Links that want to open in a new window:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In a new selected tab in the current window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In a new tab in the current window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In the current tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Http (Secure)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Http (Transparent)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use ClickToFlash on flash plugins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter Tracking Cookies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs or windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit the application when last tab is closed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable network cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> MB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose Directory...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A cookie session ends:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When I exit the application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>30 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AutoFill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AutoFill web forms:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User names and passwords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Restart required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose CSS File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SourceViewer</name>
    <message>
        <source>Loading...</source>
        <translation>Nahrávam ...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Úpr&amp;avy</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>Ná&amp;jsť</translation>
    </message>
    <message>
        <source>Source of Page </source>
        <translation type="obsolete">Zdrojový súbor</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="obsolete">&amp;Zobraziť</translation>
    </message>
    <message>
        <source>Source of Page %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation type="obsolete">&amp;Nový panel</translation>
    </message>
    <message>
        <source>Duplicate Tab</source>
        <translation>Duplikovať panel</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Zavrieť panel</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Zavrieť o&amp;statné panely</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>&amp;Obnoviť panel</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>O&amp;bnoviť všetky panely</translation>
    </message>
    <message>
        <source>Show Tab Bar</source>
        <translation>Zobraziť lištu panelov</translation>
    </message>
    <message>
        <source>Hide Tab Bar</source>
        <translation>Skryť lištu panelov</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>&amp;Nový panel</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Zavrieť panel</translation>
    </message>
    <message>
        <source>Show Next Tab</source>
        <translation>Ukázať ďalší panel</translation>
    </message>
    <message>
        <source>Show Previous Tab</source>
        <translation>Ukázať predchádzajúci panel</translation>
    </message>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Zatvorené panely</translation>
    </message>
    <message>
        <source>Do you really want to close this page?</source>
        <translation>Naozaj chcete zatvoriť tento panel?</translation>
    </message>
    <message>
        <source>You have modified this page and when closing it you would lose the modification.
Do you really want to close this page?
</source>
        <translation>Stránka bola zmenená a pri zatvorení budu všetky zmeny stratené.
Ste si istý, že chcete zavrieť túto stránku?
</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Nepomenovaný</translation>
    </message>
    <message>
        <source>Ctrl-]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl-[</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saved Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished">Nahrávam ...</translation>
    </message>
    <message>
        <source>Loading %1% (%2 %3)...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Finished loading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bookmark All Tabs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToolbarSearch</name>
    <message>
        <source>No Recent Searches</source>
        <translation>Žiadne posledné hľadania</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Posledné hľadania</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation type="unfinished">Vymazať posledné hľadania</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebPage</name>
    <message>
        <source>Error loading page: %1</source>
        <translation>Chyba pri načítavaní stránky: %1</translation>
    </message>
    <message>
        <source>When connecting to: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.arora-browser.org instead of &lt;b&gt;www&lt;/b&gt;.arora-browser.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If the address is correct, try checking the network connection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resending POST request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebView</name>
    <message>
        <source>Open in New &amp;Window</source>
        <translation>Otvoriť v &amp;novom okne</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>O&amp;tvoriť v novom paneli</translation>
    </message>
    <message>
        <source>Save Lin&amp;k</source>
        <translation>Uložiť o&amp;dkaz</translation>
    </message>
    <message>
        <source>&amp;Bookmark This Link</source>
        <translation>&amp;Vytvoriť záložku pre tento odkaz</translation>
    </message>
    <message>
        <source>&amp;Copy Link Location</source>
        <translation>&amp;Kopírovať adresu odkazu</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Window</source>
        <translation>Otvoriť obrázok v novom okne</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Tab</source>
        <translation>Otvoriť obrázok v novom paneli</translation>
    </message>
    <message>
        <source>&amp;Save Image</source>
        <translation>Uložiť obrázok</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>Kopírovať o&amp;brázok</translation>
    </message>
    <message>
        <source>C&amp;opy Image Location</source>
        <translation>Kopírovať adresu ob&amp;rázka</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Nahrávam ...</translation>
    </message>
    <message>
        <source>Search with...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to the toolbar search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Method not supported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 method is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose the desired search engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engine name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type in a name for the engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Block Image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebViewSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Neexistuje</translation>
    </message>
</context>
</TS>
